slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVDotColumnBegin

Starts a split phase dot product computation.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVDotColumnBegin(BV X,PetscInt j,PetscScalar *m)

### Input Parameters

| X | - basis vectors
| j | - the column index
| m | - an array where the result will go (can be NULL)

### Note

Each call to BVDotColumnBegin() should be paired with a call to BVDotColumnEnd().

### See Also

BVDotColumnEnd(), BVDotColumn()

### Level

advanced

### Location

src/sys/classes/bv/interface/bvglobal.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages